@@ -184,7 +184,7 @@ class Commander:
 
         Examples
         --------
-        >>> cmdr.rm('file', 'directory')
+        >>> cmdr.rm('file', 'directory') # doctest: +SKIP
         """
         for f in args:
             _delete(f)
@@ -194,7 +194,7 @@ class Commander:
 
         Examples
         --------
-        >>> cmdr.rm_on_exit('some_temporary_file')
+        >>> cmdr.rm_on_exit('some_temporary_file') # doctest: +SKIP
         """
         self._to_delete.append(Path(path).resolve())
 
@@ -213,7 +213,7 @@ class Commander:
         --------
         >>> # copies template in {templates-path}/directory/template.yaml
         >>> # to {workspace}/template.yaml
-        >>> cmdr.copy_template('directory/template.yaml')
+        >>> cmdr.copy_template('directory/template.yaml') # doctest: +SKIP
         """
         dst = Path(self.workspace, PurePosixPath(path).name)
 
@@ -245,7 +245,7 @@ class Commander:
         Examples
         --------
         >>> # copies dir/file to {workspace}/file
-        >>> cmdr.cp('dir/file')
+        >>> cmdr.cp('dir/file') # doctest: +SKIP
         """
         path = Path(src)
 
@@ -277,7 +277,7 @@ class Commander:
 
         Examples
         --------
-        >>> cmdr.append_inline('*.csv', '.gitignore')
+        >>> cmdr.append_inline('*.csv', '.gitignore') # doctest: +SKIP
         """
         if not Path(dst).exists():
             Path(dst).touch()
