@@ -68,6 +68,10 @@ from ploomber.exceptions import DAGSpecInvalidError
 from ploomber.entrypoint import try_to_find_entry_point_type, EntryPoint
 
 
+def _filesystem_root():
+    return Path(os.path.abspath(os.sep))
+
+
 def _package_location(root_path, name='pipeline.yaml'):
     """
     Look for a src/{package-name}/pipeline.yaml relative to root_path
@@ -456,6 +460,12 @@ def find_root_recursively(starting_dir=None,
         starting_dir=starting_dir,
     )
 
+    if root_by_pipeline == _filesystem_root():
+        raise DAGSpecInvalidError(
+            f'{filename} cannot be in the filesystem root. '
+            'Please add it inside a directory like '
+            f'project-name/{filename}. ')
+
     root_found = None
 
     # use found pipeline.yaml if not in a src/*/pipeline.yaml structure when
